Align class

A widget that aligns its child within itself.

Positions the child in whole terminal cells. Flutter's widthFactor and heightFactor sizing options are not supported.

This widget uses RenderPositionedBox to handle alignment positioning without relying on Container widgets to avoid circular dependencies.

Inheritance

Constructors

Align({Alignment alignment = Alignment.center, Widget? child, Key? key})
Creates an alignment widget.
const

Properties

alignment Alignment
The alignment of the child within the parent.
final
child Widget?
Optional widget attached through this render object's single-child edge.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how this widget replaces another of the same type.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited