Attr class abstract final

Terminal cell attribute bit flags.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

Blink effect.
bold → const int
Bold intensity.
dim → const int
Dim intensity.
italic → const int
Italic style.
reverse → const int
Reverse-video effect.
strike → const int
Strikethrough decoration.
underline → const int
Underline decoration.