CursorStyle enum
Cursor styles supported by terminals
Values
- block → const CursorStyle
-
Block cursor shape.
const CursorStyle(0) - underline → const CursorStyle
-
Underline cursor shape.
const CursorStyle(2) - bar → const CursorStyle
-
Vertical bar cursor shape.
const CursorStyle(1)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
Canonical OpenTUI cursor-style tag.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CursorStyle> - A constant List of the values in this enum, in order of their declaration.