FlexFit enum

How a flexible child is allowed to size itself along the main axis.

Inheritance
Available extensions

Values

tight → const FlexFit

The child is forced to fill the available space allocated to it.

loose → const FlexFit

The child can be at most as large as the available space, but may be smaller.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<FlexFit>
A constant List of the values in this enum, in order of their declaration.