ImageProtocol enum

Terminal image transport requested for a draw operation.

Inheritance
Available extensions

Values

auto → const ImageProtocol

Let OpenTUI select Kitty, Sixel, or block cells from capabilities.

kitty → const ImageProtocol

Request Kitty graphics directly.

Forced Kitty graphics through tmux are unsupported because initial placement may be incorrect until a resize. Prefer ImageProtocol.auto, which selects block cells under tmux.

sixel → const ImageProtocol

Request Sixel graphics.

blocks → const ImageProtocol

Render deterministic colored block cells.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ImageProtocol>
A constant List of the values in this enum, in order of their declaration.