InlineSpan class abstract

Base class for inline text content.

Implementers

Constructors

InlineSpan()
Creates an inline span.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

computePlainText(StringBuffer buffer) → void
Appends plain text to buffer.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPlainText() String
Returns all plain text in this span tree.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited