LogicalKeyboardKey class final
Logical keyboard key identity independent of the raw terminal sequence.
Named keys use stable constants. Printable input is represented by KeyEvent.character with a LogicalKeyboardKey.forCharacter identity so widgets can distinguish semantic controls from inserted text.
- Annotations
-
- @immutable
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
forCharacter(
String character) → LogicalKeyboardKey - Returns the logical key for printable text.
-
forDigit(
String digit) → LogicalKeyboardKey - Returns the logical key for an ASCII digit.
-
forLetter(
String lowerAsciiLetter) → LogicalKeyboardKey - Returns the logical key for an ASCII letter.
Constants
- alt → const LogicalKeyboardKey
- Alt modifier pseudo-key.
- arrowDown → const LogicalKeyboardKey
- Arrow-down key.
- arrowLeft → const LogicalKeyboardKey
- Arrow-left key.
- arrowRight → const LogicalKeyboardKey
- Arrow-right key.
- arrowUp → const LogicalKeyboardKey
- Arrow-up key.
- backspace → const LogicalKeyboardKey
- Backspace key.
- control → const LogicalKeyboardKey
- Control modifier pseudo-key.
- delete → const LogicalKeyboardKey
- Delete key.
- digit0 → const LogicalKeyboardKey
- Digit 0 key.
- digit1 → const LogicalKeyboardKey
- Digit 1 key.
- digit2 → const LogicalKeyboardKey
- Digit 2 key.
- digit3 → const LogicalKeyboardKey
- Digit 3 key.
- digit4 → const LogicalKeyboardKey
- Digit 4 key.
- digit5 → const LogicalKeyboardKey
- Digit 5 key.
- digit6 → const LogicalKeyboardKey
- Digit 6 key.
- digit7 → const LogicalKeyboardKey
- Digit 7 key.
- digit8 → const LogicalKeyboardKey
- Digit 8 key.
- digit9 → const LogicalKeyboardKey
- Digit 9 key.
- end → const LogicalKeyboardKey
- End key.
- enter → const LogicalKeyboardKey
- Enter/return key.
- escape → const LogicalKeyboardKey
- Escape key.
- f1 → const LogicalKeyboardKey
- F1 key.
- f2 → const LogicalKeyboardKey
- F2 key.
- f3 → const LogicalKeyboardKey
- F3 key.
- f4 → const LogicalKeyboardKey
- F4 key.
- f5 → const LogicalKeyboardKey
- F5 key.
- f6 → const LogicalKeyboardKey
- F6 key.
- f7 → const LogicalKeyboardKey
- F7 key.
- f8 → const LogicalKeyboardKey
- F8 key.
- f9 → const LogicalKeyboardKey
- F9 key.
- f10 → const LogicalKeyboardKey
- F10 key.
- f11 → const LogicalKeyboardKey
- F11 key.
- f12 → const LogicalKeyboardKey
- F12 key.
- home → const LogicalKeyboardKey
- Home key.
- insert → const LogicalKeyboardKey
- Insert key.
- keyA → const LogicalKeyboardKey
- Letter A key.
- keyB → const LogicalKeyboardKey
- Letter B key.
- keyC → const LogicalKeyboardKey
- Letter C key.
- keyD → const LogicalKeyboardKey
- Letter D key.
- keyE → const LogicalKeyboardKey
- Letter E key.
- keyF → const LogicalKeyboardKey
- Letter F key.
- keyG → const LogicalKeyboardKey
- Letter G key.
- keyH → const LogicalKeyboardKey
- Letter H key.
- keyI → const LogicalKeyboardKey
- Letter I key.
- keyJ → const LogicalKeyboardKey
- Letter J key.
- keyK → const LogicalKeyboardKey
- Letter K key.
- keyL → const LogicalKeyboardKey
- Letter L key.
- keyM → const LogicalKeyboardKey
- Letter M key.
- keyN → const LogicalKeyboardKey
- Letter N key.
- keyO → const LogicalKeyboardKey
- Letter O key.
- keyP → const LogicalKeyboardKey
- Letter P key.
- keyQ → const LogicalKeyboardKey
- Letter Q key.
- keyR → const LogicalKeyboardKey
- Letter R key.
- keyS → const LogicalKeyboardKey
- Letter S key.
- keyT → const LogicalKeyboardKey
- Letter T key.
- keyU → const LogicalKeyboardKey
- Letter U key.
- keyV → const LogicalKeyboardKey
- Letter V key.
- keyW → const LogicalKeyboardKey
- Letter W key.
- keyX → const LogicalKeyboardKey
- Letter X key.
- keyY → const LogicalKeyboardKey
- Letter Y key.
- keyZ → const LogicalKeyboardKey
- Letter Z key.
- meta → const LogicalKeyboardKey
- Meta modifier pseudo-key.
- pageDown → const LogicalKeyboardKey
- Page-down key.
- pageUp → const LogicalKeyboardKey
- Page-up key.
- shift → const LogicalKeyboardKey
- Shift modifier pseudo-key.
- space → const LogicalKeyboardKey
- Space key.
- tab → const LogicalKeyboardKey
- Tab key.
- unknown → const LogicalKeyboardKey
- Unknown/unmapped key.