dismissOnOutsideClick property
Whether an outside primary-button press closes the modal.
All outside pointer events are blocked regardless of this value.
Implementation
final bool dismissOnOutsideClick;
Whether an outside primary-button press closes the modal.
All outside pointer events are blocked regardless of this value.
final bool dismissOnOutsideClick;