Size class

A 2D size in terminal character cells.

Annotations
  • @immutable

Constructors

Size(int width, int height)
Stores non-negative width and height extents in terminal cells.
const
Size.square(int dimension)
Creates a square size with both dimensions equal to dimension.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
height int
Vertical extent in terminal character cells.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
Horizontal extent in terminal character cells.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

zero → const Size
Canonical size with zero width and height.