StatefulWidget class abstract

A widget that has mutable state managed by a State object.

Inheritance
Implementers

Constructors

StatefulWidget({Key? key})
Creates a stateful widget with an optional key.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how this widget replaces another of the same type.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createState() State<StatefulWidget>
Creates the mutable State for this widget.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited