TerminalImageInfo class final

Immutable decoded-image metadata.

Annotations
  • @immutable

Constructors

TerminalImageInfo({required int pixelWidth, required int pixelHeight, required int sourcePixelWidth, required int sourcePixelHeight, required ImageFormat format, required ImageColorStatus colorStatus, required int orientation, required bool hasAlpha})
Creates decoded image metadata.
const

Properties

colorStatus ImageColorStatus
Color-profile interpretation.
final
format ImageFormat
Source format.
final
hasAlpha bool
Whether decoded pixels may contain transparency.
final
hashCode int
The hash code for this object.
no setterinherited
orientation int
EXIF orientation value.
final
pixelHeight int
Display-oriented pixel height.
final
pixelWidth int
Display-oriented pixel width.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourcePixelHeight int
Source pixel height before orientation is applied.
final
sourcePixelWidth int
Source pixel width before orientation is applied.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited