TextLayoutLine class final

One laid-out terminal text line.

Constructors

TextLayoutLine({required List<TextLayoutRun> runs, required int width})
Creates a laid-out text line.

Properties

hashCode int
The hash code for this object.
no setterinherited
runs List<TextLayoutRun>
Styled runs on this line.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
Plain text for this line.
no setter
width int
Width in terminal cells.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited