Widget class abstract

Immutable description of part of the user interface.

Implementers

Constructors

Widget({Key? key})
Creates a widget with an optional key.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how this widget replaces another of the same type.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

canUpdate(Widget oldWidget, Widget newWidget) bool
Whether oldWidget's element can be updated to newWidget.