Wrap class

Arranges children into horizontal or vertical runs.

Inheritance

Constructors

Wrap({Key? key, List<Widget> children = const <Widget>[], Axis direction = Axis.horizontal, int spacing = 0, int runSpacing = 0, WrapAlignment alignment = WrapAlignment.start, WrapAlignment runAlignment = WrapAlignment.start, WrapCrossAlignment crossAxisAlignment = WrapCrossAlignment.start})
Creates a wrapping layout in whole terminal cells.
const

Properties

alignment WrapAlignment
Distribution of children within each run.
final
children List<Widget>
The widgets below this widget in the tree
finalinherited
crossAxisAlignment WrapCrossAlignment
Placement of children within each run's cross extent.
final
direction Axis
Axis along which children fill each run.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how this widget replaces another of the same type.
finalinherited
runAlignment WrapAlignment
Distribution of runs across the cross axis.
final
runSpacing int
Cells between adjacent runs.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing int
Cells between adjacent children.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited