OpenTuiHandle class sealed

Strongly typed OpenTUI v0.5.1 handle value.

Implementers
Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
Nonzero unsigned 32-bit value issued by OpenTUI.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

checked(int value, String name) → int
Validates and returns a canonical nonzero u32 handle value.