OptimizedBufferHandle class final

Native optimized-buffer handle borrowed from a renderer.

Inheritance

Constructors

OptimizedBufferHandle.fromNative(int value)
Creates a buffer handle from its canonical native value.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
Nonzero unsigned 32-bit value issued by OpenTUI.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited