DirectBufferAccess class

Direct access to Buffer internal arrays for advanced operations.

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → int
Height of the buffer in cells.
no setter
length → int
Get buffer length (width * height).
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int
Width of the buffer in cells.
no setter

Methods

getAttributes(int x, int y) → int
u32 attribute word at cell (x, y).
getBackground(int x, int y) → Color
Packed RGBA background at cell (x, y).
getChar(int x, int y) → String
Decodes a direct Unicode-scalar cell at the specified coordinates.
getEncodedCellAt(int cellIndex) → int
Reads one native encoded cell word by row-major cellIndex.
getForeground(int x, int y) → Color
Packed RGBA foreground at cell (x, y).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAttributes(int x, int y, int attr) → void
Set text attributes at the specified coordinates.
setBackground(int x, int y, Color color) → void
Stores packed RGBA background at cell (x, y).
setChar(int x, int y, String char) → void
Stores the first Unicode scalar from a non-empty char.
setEncodedCellAt(int cellIndex, int value) → void
Writes one native encoded cell word by row-major cellIndex.
setForeground(int x, int y, Color color) → void
Stores packed RGBA foreground at cell (x, y).
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited