PaintingContext class final

Context passed through the render-tree paint walk.

Constructors

PaintingContext(TuiCanvas canvas, {TerminalCellMetrics cellMetrics = const TerminalCellMetrics(columns: 0, rows: 0)})
Creates a painting context backed by canvas.
const

Properties

canvas TuiCanvas
Canvas that records paint commands for the current frame.
final
cellMetrics TerminalCellMetrics
Terminal cell and optional physical-pixel metrics for this frame.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paintChild(RenderObject child, Offset offset) → void
Paint child at offset.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited