RenderObjectWidget class abstract

Base class for widgets that manage RenderObjects

RenderObjectWidget creates and configures RenderObjects that handle layout and painting. This follows the Flutter pattern of Widget → Element → RenderObject.

Inheritance
Implementers

Constructors

RenderObjectWidget({Key? key})
Initializes a widget whose element creates and configures a RenderObject.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how this widget replaces another of the same type.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createRenderObject(BuildContext context) RenderObject
Create the RenderObject for this widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateRenderObject(BuildContext context, covariant RenderObject renderObject) → void
Update the RenderObject with new configuration

Operators

operator ==(Object other) bool
The equality operator.
inherited