RenderWrap class final

A render box that lays children into multiple runs.

Inheritance

Constructors

RenderWrap({Axis direction = Axis.horizontal, int spacing = 0, int runSpacing = 0, WrapAlignment alignment = WrapAlignment.start, WrapAlignment runAlignment = WrapAlignment.start, WrapCrossAlignment crossAxisAlignment = WrapCrossAlignment.start, List<RenderBox>? children})
Creates a wrapping layout.

Properties

alignment ↔ WrapAlignment
Distribution of children within each run.
getter/setter pair
children → List<RenderObject>
Live read-only view of direct children in traversal order.
latefinalinherited
crossAxisAlignment ↔ WrapCrossAlignment
Placement of children within each run's cross extent.
getter/setter pair
debugNeedsLayout → bool
Whether this render object is waiting for layout.
no setterinherited
debugNeedsPaint → bool
Whether this render object is waiting for paint.
no setterinherited
direction ↔ Axis
Axis along which children are added to a run.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
Height in terminal cells, assigned during layout.
getter/setter pairinherited
parent → RenderObject?
Parent RenderObject in the tree.
no setterinherited
runAlignment ↔ WrapAlignment
Distribution of runs across the cross axis.
getter/setter pair
runSpacing ↔ int
Cells between adjacent runs.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ Size
The current size of this box, or Size.zero if not laid out
getter/setter pairinherited
spacing ↔ int
Cells between adjacent children in a run.
getter/setter pair
width ↔ int
Width in terminal cells, assigned during layout.
getter/setter pairinherited
x ↔ int
Horizontal position in terminal cells, relative to the parent.
getter/setter pairinherited
y ↔ int
Vertical position in terminal cells, relative to the parent.
getter/setter pairinherited

Methods

adoptChild(RenderObject child) → void
Add a child to this render object
inherited
detach() → void
Called when the render object is detached from the render tree.
inherited
dropChild(RenderObject child) → void
Remove a child from this render object
inherited
hitTest(HitTestResult result, Offset position) → bool
Hit-test this render object using position in local coordinates.
inherited
hitTestChildren(HitTestResult result, Offset position) → bool
Hit-test children in reverse paint order.
inherited
hitTestSelf(Offset position) → bool
Whether this box should add itself to a hit-test path.
inherited
layout(Constraints constraints) → void
Entry point for layout.
inherited
markNeedsLayout() → void
Mark this render object as needing layout and paint.
inherited
markNeedsPaint() → void
Mark this render object as needing paint.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(PaintingContext context, Offset offset) → void
Default paint implementation.
inherited
performBoxLayout(BoxConstraints constraints) → void
Perform layout with typed box constraints
override
performLayout(Constraints constraints) → void
Perform layout with box constraints
inherited
positionChild(RenderBox child, int x, int y) → void
Position a child within this box
inherited
toString() → String
A string representation of this object.
inherited
visitChildren(void visitor(RenderObject child)) → void
Visit all children with a callback
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited