SingleChildRenderObjectWidget class abstract

A RenderObjectWidget whose render object adopts at most one child.

Inheritance
Implementers

Constructors

SingleChildRenderObjectWidget({Key? key, Widget? child})
Initializes a render-object widget with an optional single child.
const

Properties

child Widget?
Optional widget attached through this render object's single-child edge.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how this widget replaces another of the same type.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createRenderObject(BuildContext context) RenderObject
Create the RenderObject for this widget
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateRenderObject(BuildContext context, covariant RenderObject renderObject) → void
Update the RenderObject with new configuration
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited