StackChildData class final

Absolute positioning metadata for one stack child.

Annotations
  • @immutable

Constructors

StackChildData({int? left, int? top, int? right, int? bottom, int? width, int? height})
Creates positioning metadata in whole terminal cells.
const

Properties

bottom → int?
Distance from the stack's bottom edge.
final
hashCode → int
The hash code for this object.
no setteroverride
height → int?
Explicit child height.
final
isPositioned → bool
Whether this child participates in absolute positioning.
no setter
left → int?
Distance from the stack's left edge.
final
Distance from the stack's right edge.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top → int?
Distance from the stack's top edge.
final
width → int?
Explicit child width.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override