debugHasScheduledFrame property
Whether the scheduler has a pending frame in integration tests.
Implementation
@visibleForTesting
bool get debugHasScheduledFrame => _scheduler.hasScheduledFrame;
Whether the scheduler has a pending frame in integration tests.
@visibleForTesting
bool get debugHasScheduledFrame => _scheduler.hasScheduledFrame;