BorderSides class final
Selects which sides of a terminal box are drawn.
Constructors
- BorderSides({bool top = true, bool right = true, bool bottom = true, bool left = true})
-
Creates a side mask.
const
Properties
- bottom → bool
-
Whether to draw the bottom side.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- left → bool
-
Whether to draw the left side.
final
- right → bool
-
Whether to draw the right side.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- top → bool
-
Whether to draw the top side.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited