EdgeInsets class
Insets from each edge of a rectangle, in terminal character cells.
- Annotations
-
- @immutable
Constructors
- EdgeInsets({int left = 0, int top = 0, int right = 0, int bottom = 0})
-
Creates insets with independent edges; each defaults to 0.
const
- EdgeInsets.all(int v)
-
Creates insets with the same value
von all four edges.const - EdgeInsets.only({int left = 0, int top = 0, int right = 0, int bottom = 0})
-
Creates insets with only the specified edges set; others default to 0.
const
- EdgeInsets.symmetric({int vertical = 0, int horizontal = 0})
-
Creates insets where
verticalsets top/bottom andhorizontalsets left/right.const
Properties
- bottom → int
-
Non-negative bottom inset in terminal character cells.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isNonNegative → bool
-
Whether every dimension is non-negative.
no setter
- left → int
-
Non-negative left inset in terminal character cells.
final
- right → int
-
Non-negative right inset in terminal character cells.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- top → int
-
Non-negative top inset in terminal character cells.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- zero → const EdgeInsets
- An EdgeInsets with zero offsets in each direction.