PasteEvent class
A bracketed-paste block delivered as a single event instead of one synthetic key event per character. Subscribe via InputManager.onPaste.
Constructors
- PasteEvent(String text)
-
Delivers
textas one consumable bracketed-paste event.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConsumed → bool
-
Whether
consumehas been called on this event.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
The pasted text content delivered as a single block.
final
Methods
-
consume(
) → void -
Stop further dispatch of this event.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited