Size class
A 2D size in terminal character cells.
- Annotations
-
- @immutable
Constructors
- Size(int width, int height)
-
Stores non-negative
widthandheightextents in terminal cells.const - Size.square(int dimension)
-
Creates a square size with both dimensions equal to
dimension.const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override