StatefulWidget class abstract
A widget that has mutable state managed by a State object.
Constructors
- StatefulWidget({Key? key})
-
Creates a stateful widget with an optional
key.const
Properties
Methods
-
createState(
) → State< StatefulWidget> - Creates the mutable State for this widget.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited