TextStyles class
Pre-defined text styles for common use cases
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- bold → const TextStyle
- Text with the terminal bold attribute.
- code → const TextStyle
- Code preset with light text on a dark background.
- dim → const TextStyle
- Text with the terminal dim attribute.
- error → const TextStyle
- Error preset with a red foreground.
- h1 → const TextStyle
- First-level heading preset using bold text.
- h2 → const TextStyle
- Second-level heading preset using bold, underlined, light text.
- h3 → const TextStyle
- Third-level heading preset using bold light-gray text.
- highlight → const TextStyle
- Highlight preset with black text on a yellow background.
- info → const TextStyle
-
Informational preset with normalized RGB
(0, 0.7, 1). - italic → const TextStyle
- Text with the terminal italic attribute.
- link → const TextStyle
- Link preset with blue, underlined text.
- muted → const TextStyle
- Muted preset with a gray foreground.
- normal → const TextStyle
- Default text style with no added terminal attributes.
- selection → const TextStyle
-
Selection preset with normalized RGB
(0, 0, 0.8)as its background. - success → const TextStyle
- Success preset with a green foreground.
- underline → const TextStyle
- Text with the terminal underline attribute.
- warning → const TextStyle
- Warning preset with a yellow foreground.