OptimizedBufferHandle class final
Native optimized-buffer handle borrowed from a renderer.
- Inheritance
-
- Object
- OpenTuiHandle
- OptimizedBufferHandle
Constructors
- OptimizedBufferHandle.fromNative(int value)
- Creates a buffer handle from its canonical native value.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited