TerminalCellMetrics class final

Terminal geometry available during a render-tree paint walk.

Annotations
  • @immutable

Constructors

TerminalCellMetrics({required int columns, required int rows, int? pixelWidth, int? pixelHeight})
Creates cell metrics for a terminal viewport.
const

Properties

columns int
Terminal viewport width in cells.
final
hashCode int
The hash code for this object.
no setteroverride
nominalCellAspectRatio double
Nominal terminal cell width-to-height ratio used without measurement.
no setter
pixelHeight int?
Measured terminal viewport height in pixels, when positive and available.
final
pixelsPerCellX double?
Measured pixels per cell column, when resolution is usable.
no setter
pixelsPerCellY double?
Measured pixels per cell row, when resolution is usable.
no setter
pixelWidth int?
Measured terminal viewport width in pixels, when positive and available.
final
rows int
Terminal viewport height in cells.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override